Index: sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart |
diff --git a/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart b/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart |
index 1d612a1b6162a8d6523aa8b8bc274dab54b246ea..e84f4e8cd16c7e48823c0653713bbf01f8afe057 100644 |
--- a/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart |
+++ b/sdk/lib/_internal/pub/test/cache/repair/updates_binstubs_test.dart |
@@ -57,8 +57,8 @@ main() { |
// The broken versions should have been replaced. |
d.dir(cachePath, [ |
d.dir('bin', [ |
- // 255 is the VM's exit code upon seeing an out-of-date snapshot. |
- d.matcherFile(binStubName('foo-script'), contains('255')) |
+ // 253 is the VM's exit code upon seeing an out-of-date snapshot. |
+ d.matcherFile(binStubName('foo-script'), contains('253')) |
]) |
]).validate(); |
}); |